==> haskell-cheapskate-0.1.1-122-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1
id: cheapskate-0.1.1-2VgxTiFQc8Y4F8lCCQRdQw
key: cheapskate-0.1.1-2VgxTiFQc8Y4F8lCCQRdQw
license: BSD-3-Clause
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
abi: 7b50233eb7697c72596699cbef7b0359
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
import-dirs: /usr/lib/ghc-8.4.3/site-local/cheapskate-0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/cheapskate-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cheapskate-0.1.1
hs-libraries: HScheapskate-0.1.1-2VgxTiFQc8Y4F8lCCQRdQw
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2 text-1.2.3.0
    blaze-html-0.9.1.1-7NSQK15kZm4LYXM6mugOc0
    xss-sanitize-0.3.6-DkbdY2Ljkwa9tv5YXNairQ
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
    syb-0.7-2jW43lwzJV5e7EQvU8PxV
    uniplate-1.6.12-7qe1vfYGuTJA8QWKhCYPuR deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             blaze-html-0.9.1.1-7NSQK15kZm4LYXM6mugOc0=b90977d0094d15b5bd9e12114444ef75
             xss-sanitize-0.3.6-DkbdY2Ljkwa9tv5YXNairQ=aa87cfe59c2112cd2603a78c22b6457c
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             uniplate-1.6.12-7qe1vfYGuTJA8QWKhCYPuR=defe324fb2523260f738fbe6393c2beb
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1-123-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1
id: cheapskate-0.1.1-D08GqKK84otGXXMcTwsF00
key: cheapskate-0.1.1-D08GqKK84otGXXMcTwsF00
license: BSD-3-Clause
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
abi: be3c73e6634d8effd62ebc2b60a69a11
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
import-dirs: /usr/lib/ghc-8.4.3/site-local/cheapskate-0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/cheapskate-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cheapskate-0.1.1
hs-libraries: HScheapskate-0.1.1-D08GqKK84otGXXMcTwsF00
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2 text-1.2.3.0
    blaze-html-0.9.1.1-7NSQK15kZm4LYXM6mugOc0
    xss-sanitize-0.3.6-F8WSF38yx4EKmhGHLekXJr
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
    syb-0.7-2jW43lwzJV5e7EQvU8PxV
    uniplate-1.6.12-7qe1vfYGuTJA8QWKhCYPuR deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             blaze-html-0.9.1.1-7NSQK15kZm4LYXM6mugOc0=b90977d0094d15b5bd9e12114444ef75
             xss-sanitize-0.3.6-F8WSF38yx4EKmhGHLekXJr=43fb8b64047a22cb3dff15b6cc6ea337
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             uniplate-1.6.12-7qe1vfYGuTJA8QWKhCYPuR=defe324fb2523260f738fbe6393c2beb
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
